# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/tendermint/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from tendermint.p2p import types_pb2 as tendermint_dot_p2p_dot_types__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from cosmos.base.tendermint.v1beta1 import types_pb2 as cosmos_dot_base_dot_tendermint_dot_v1beta1_dot_types__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cosmos/base/tendermint/v1beta1/query.proto\x12\x1e\x63osmos.base.tendermint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1atendermint/p2p/types.proto\x1a\x1ctendermint/types/types.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a*cosmos/base/tendermint/v1beta1/types.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1ctendermint/types/block.proto\x1a\x11\x61mino/amino.proto\"l\n\x1eGetValidatorSetByHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xb3\x01\n\x1fGetValidatorSetByHeightResponse\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x03\x12=\n\nvalidators\x18\x02 \x03(\x0b\x32).cosmos.base.tendermint.v1beta1.Validator\x12;\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"Z\n\x1cGetLatestValidatorSetRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xb1\x01\n\x1dGetLatestValidatorSetResponse\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x03\x12=\n\nvalidators\x18\x02 \x03(\x0b\x32).cosmos.base.tendermint.v1beta1.Validator\x12;\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x8e\x01\n\tValidator\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12%\n\x07pub_key\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x14\n\x0cvoting_power\x18\x03 \x01(\x03\x12\x19\n\x11proposer_priority\x18\x04 \x01(\x03\")\n\x17GetBlockByHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"\xa9\x01\n\x18GetBlockByHeightResponse\x12+\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x19.tendermint.types.BlockID\x12&\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x17.tendermint.types.Block\x12\x38\n\tsdk_block\x18\x03 \x01(\x0b\x32%.cosmos.base.tendermint.v1beta1.Block\"\x17\n\x15GetLatestBlockRequest\"\xa7\x01\n\x16GetLatestBlockResponse\x12+\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x19.tendermint.types.BlockID\x12&\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x17.tendermint.types.Block\x12\x38\n\tsdk_block\x18\x03 \x01(\x0b\x32%.cosmos.base.tendermint.v1beta1.Block\"\x13\n\x11GetSyncingRequest\"%\n\x12GetSyncingResponse\x12\x0f\n\x07syncing\x18\x01 \x01(\x08\"\x14\n\x12GetNodeInfoRequest\"\x9b\x01\n\x13GetNodeInfoResponse\x12:\n\x11\x64\x65\x66\x61ult_node_info\x18\x01 \x01(\x0b\x32\x1f.tendermint.p2p.DefaultNodeInfo\x12H\n\x13\x61pplication_version\x18\x02 \x01(\x0b\x32+.cosmos.base.tendermint.v1beta1.VersionInfo\"\xd2\x01\n\x0bVersionInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x12\n\ngit_commit\x18\x04 \x01(\t\x12\x12\n\nbuild_tags\x18\x05 \x01(\t\x12\x12\n\ngo_version\x18\x06 \x01(\t\x12:\n\nbuild_deps\x18\x07 \x03(\x0b\x32&.cosmos.base.tendermint.v1beta1.Module\x12\x1a\n\x12\x63osmos_sdk_version\x18\x08 \x01(\t\"4\n\x06Module\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0b\n\x03sum\x18\x03 \x01(\t\"M\n\x10\x41\x42\x43IQueryRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\r\n\x05prove\x18\x04 \x01(\x08\"\xcd\x01\n\x11\x41\x42\x43IQueryResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x03\x12\x0b\n\x03key\x18\x06 \x01(\x0c\x12\r\n\x05value\x18\x07 \x01(\x0c\x12;\n\tproof_ops\x18\x08 \x01(\x0b\x32(.cosmos.base.tendermint.v1beta1.ProofOps\x12\x0e\n\x06height\x18\t \x01(\x03\x12\x11\n\tcodespace\x18\n \x01(\tJ\x04\x08\x02\x10\x03\"2\n\x07ProofOp\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"K\n\x08ProofOps\x12?\n\x03ops\x18\x01 \x03(\x0b\x32\'.cosmos.base.tendermint.v1beta1.ProofOpB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\xaf\n\n\x07Service\x12\xa9\x01\n\x0bGetNodeInfo\x12\x32.cosmos.base.tendermint.v1beta1.GetNodeInfoRequest\x1a\x33.cosmos.base.tendermint.v1beta1.GetNodeInfoResponse\"1\x82\xd3\xe4\x93\x02+\x12)/cosmos/base/tendermint/v1beta1/node_info\x12\xa4\x01\n\nGetSyncing\x12\x31.cosmos.base.tendermint.v1beta1.GetSyncingRequest\x1a\x32.cosmos.base.tendermint.v1beta1.GetSyncingResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/base/tendermint/v1beta1/syncing\x12\xb6\x01\n\x0eGetLatestBlock\x12\x35.cosmos.base.tendermint.v1beta1.GetLatestBlockRequest\x1a\x36.cosmos.base.tendermint.v1beta1.GetLatestBlockResponse\"5\x82\xd3\xe4\x93\x02/\x12-/cosmos/base/tendermint/v1beta1/blocks/latest\x12\xbe\x01\n\x10GetBlockByHeight\x12\x37.cosmos.base.tendermint.v1beta1.GetBlockByHeightRequest\x1a\x38.cosmos.base.tendermint.v1beta1.GetBlockByHeightResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//cosmos/base/tendermint/v1beta1/blocks/{height}\x12\xd2\x01\n\x15GetLatestValidatorSet\x12<.cosmos.base.tendermint.v1beta1.GetLatestValidatorSetRequest\x1a=.cosmos.base.tendermint.v1beta1.GetLatestValidatorSetResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/tendermint/v1beta1/validatorsets/latest\x12\xda\x01\n\x17GetValidatorSetByHeight\x12>.cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightRequest\x1a?.cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/cosmos/base/tendermint/v1beta1/validatorsets/{height}\x12\xa4\x01\n\tABCIQuery\x12\x30.cosmos.base.tendermint.v1beta1.ABCIQueryRequest\x1a\x31.cosmos.base.tendermint.v1beta1.ABCIQueryResponse\"2\x82\xd3\xe4\x93\x02,\x12*/cosmos/base/tendermint/v1beta1/abci_queryB4Z2github.com/cosmos/cosmos-sdk/client/grpc/tmserviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.tendermint.v1beta1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/cosmos/cosmos-sdk/client/grpc/tmservice'
  _VALIDATOR.fields_by_name['address']._options = None
  _VALIDATOR.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _PROOFOPS.fields_by_name['ops']._options = None
  _PROOFOPS.fields_by_name['ops']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _SERVICE.methods_by_name['GetNodeInfo']._options = None
  _SERVICE.methods_by_name['GetNodeInfo']._serialized_options = b'\202\323\344\223\002+\022)/cosmos/base/tendermint/v1beta1/node_info'
  _SERVICE.methods_by_name['GetSyncing']._options = None
  _SERVICE.methods_by_name['GetSyncing']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/base/tendermint/v1beta1/syncing'
  _SERVICE.methods_by_name['GetLatestBlock']._options = None
  _SERVICE.methods_by_name['GetLatestBlock']._serialized_options = b'\202\323\344\223\002/\022-/cosmos/base/tendermint/v1beta1/blocks/latest'
  _SERVICE.methods_by_name['GetBlockByHeight']._options = None
  _SERVICE.methods_by_name['GetBlockByHeight']._serialized_options = b'\202\323\344\223\0021\022//cosmos/base/tendermint/v1beta1/blocks/{height}'
  _SERVICE.methods_by_name['GetLatestValidatorSet']._options = None
  _SERVICE.methods_by_name['GetLatestValidatorSet']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/tendermint/v1beta1/validatorsets/latest'
  _SERVICE.methods_by_name['GetValidatorSetByHeight']._options = None
  _SERVICE.methods_by_name['GetValidatorSetByHeight']._serialized_options = b'\202\323\344\223\0028\0226/cosmos/base/tendermint/v1beta1/validatorsets/{height}'
  _SERVICE.methods_by_name['ABCIQuery']._options = None
  _SERVICE.methods_by_name['ABCIQuery']._serialized_options = b'\202\323\344\223\002,\022*/cosmos/base/tendermint/v1beta1/abci_query'
  _globals['_GETVALIDATORSETBYHEIGHTREQUEST']._serialized_start=379
  _globals['_GETVALIDATORSETBYHEIGHTREQUEST']._serialized_end=487
  _globals['_GETVALIDATORSETBYHEIGHTRESPONSE']._serialized_start=490
  _globals['_GETVALIDATORSETBYHEIGHTRESPONSE']._serialized_end=669
  _globals['_GETLATESTVALIDATORSETREQUEST']._serialized_start=671
  _globals['_GETLATESTVALIDATORSETREQUEST']._serialized_end=761
  _globals['_GETLATESTVALIDATORSETRESPONSE']._serialized_start=764
  _globals['_GETLATESTVALIDATORSETRESPONSE']._serialized_end=941
  _globals['_VALIDATOR']._serialized_start=944
  _globals['_VALIDATOR']._serialized_end=1086
  _globals['_GETBLOCKBYHEIGHTREQUEST']._serialized_start=1088
  _globals['_GETBLOCKBYHEIGHTREQUEST']._serialized_end=1129
  _globals['_GETBLOCKBYHEIGHTRESPONSE']._serialized_start=1132
  _globals['_GETBLOCKBYHEIGHTRESPONSE']._serialized_end=1301
  _globals['_GETLATESTBLOCKREQUEST']._serialized_start=1303
  _globals['_GETLATESTBLOCKREQUEST']._serialized_end=1326
  _globals['_GETLATESTBLOCKRESPONSE']._serialized_start=1329
  _globals['_GETLATESTBLOCKRESPONSE']._serialized_end=1496
  _globals['_GETSYNCINGREQUEST']._serialized_start=1498
  _globals['_GETSYNCINGREQUEST']._serialized_end=1517
  _globals['_GETSYNCINGRESPONSE']._serialized_start=1519
  _globals['_GETSYNCINGRESPONSE']._serialized_end=1556
  _globals['_GETNODEINFOREQUEST']._serialized_start=1558
  _globals['_GETNODEINFOREQUEST']._serialized_end=1578
  _globals['_GETNODEINFORESPONSE']._serialized_start=1581
  _globals['_GETNODEINFORESPONSE']._serialized_end=1736
  _globals['_VERSIONINFO']._serialized_start=1739
  _globals['_VERSIONINFO']._serialized_end=1949
  _globals['_MODULE']._serialized_start=1951
  _globals['_MODULE']._serialized_end=2003
  _globals['_ABCIQUERYREQUEST']._serialized_start=2005
  _globals['_ABCIQUERYREQUEST']._serialized_end=2082
  _globals['_ABCIQUERYRESPONSE']._serialized_start=2085
  _globals['_ABCIQUERYRESPONSE']._serialized_end=2290
  _globals['_PROOFOP']._serialized_start=2292
  _globals['_PROOFOP']._serialized_end=2342
  _globals['_PROOFOPS']._serialized_start=2344
  _globals['_PROOFOPS']._serialized_end=2419
  _globals['_SERVICE']._serialized_start=2422
  _globals['_SERVICE']._serialized_end=3749
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/ack.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/applications/fee/v1/ack.proto\x12\x17ibc.applications.fee.v1\x1a\x14gogoproto/gogo.proto\"\xe3\x01\n\x1bIncentivizedAcknowledgement\x12;\n\x13\x61pp_acknowledgement\x18\x01 \x01(\x0c\x42\x1e\xf2\xde\x1f\x1ayaml:\"app_acknowledgement\"\x12\x43\n\x17\x66orward_relayer_address\x18\x02 \x01(\tB\"\xf2\xde\x1f\x1eyaml:\"forward_relayer_address\"\x12\x42\n\x16underlying_app_success\x18\x03 \x01(\x08\x42\"\xf2\xde\x1f\x1eyaml:\"underlying_app_successl\"B7Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.ack_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _INCENTIVIZEDACKNOWLEDGEMENT.fields_by_name['app_acknowledgement']._options = None
  _INCENTIVIZEDACKNOWLEDGEMENT.fields_by_name['app_acknowledgement']._serialized_options = b'\362\336\037\032yaml:\"app_acknowledgement\"'
  _INCENTIVIZEDACKNOWLEDGEMENT.fields_by_name['forward_relayer_address']._options = None
  _INCENTIVIZEDACKNOWLEDGEMENT.fields_by_name['forward_relayer_address']._serialized_options = b'\362\336\037\036yaml:\"forward_relayer_address\"'
  _INCENTIVIZEDACKNOWLEDGEMENT.fields_by_name['underlying_app_success']._options = None
  _INCENTIVIZEDACKNOWLEDGEMENT.fields_by_name['underlying_app_success']._serialized_options = b'\362\336\037\036yaml:\"underlying_app_successl\"'
  _globals['_INCENTIVIZEDACKNOWLEDGEMENT']._serialized_start=85
  _globals['_INCENTIVIZEDACKNOWLEDGEMENT']._serialized_end=312
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/controller/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.applications.interchain_accounts.v1 import packet_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_v1_dot_packet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;ibc/applications/interchain_accounts/controller/v1/tx.proto\x12\x32ibc.applications.interchain_accounts.controller.v1\x1a\x14gogoproto/gogo.proto\x1a\x34ibc/applications/interchain_accounts/v1/packet.proto\"y\n\x1cMsgRegisterInterchainAccount\x12\r\n\x05owner\x18\x01 \x01(\t\x12/\n\rconnection_id\x18\x02 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\x12\x0f\n\x07version\x18\x03 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"v\n$MsgRegisterInterchainAccountResponse\x12)\n\nchannel_id\x18\x01 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12#\n\x07port_id\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\"\x83\x02\n\tMsgSendTx\x12\r\n\x05owner\x18\x01 \x01(\t\x12/\n\rconnection_id\x18\x02 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\x12u\n\x0bpacket_data\x18\x03 \x01(\x0b\x32\x44.ibc.applications.interchain_accounts.v1.InterchainAccountPacketDataB\x1a\xc8\xde\x1f\x00\xf2\xde\x1f\x12yaml:\"packet_data\"\x12\x35\n\x10relative_timeout\x18\x04 \x01(\x04\x42\x1b\xf2\xde\x1f\x17yaml:\"relative_timeout\":\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"%\n\x11MsgSendTxResponse\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x32\xe0\x02\n\x03Msg\x12\xc7\x01\n\x19RegisterInterchainAccount\x12P.ibc.applications.interchain_accounts.controller.v1.MsgRegisterInterchainAccount\x1aX.ibc.applications.interchain_accounts.controller.v1.MsgRegisterInterchainAccountResponse\x12\x8e\x01\n\x06SendTx\x12=.ibc.applications.interchain_accounts.controller.v1.MsgSendTx\x1a\x45.ibc.applications.interchain_accounts.controller.v1.MsgSendTxResponseBRZPgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/controller/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/controller/types'
  _MSGREGISTERINTERCHAINACCOUNT.fields_by_name['connection_id']._options = None
  _MSGREGISTERINTERCHAINACCOUNT.fields_by_name['connection_id']._serialized_options = b'\362\336\037\024yaml:\"connection_id\"'
  _MSGREGISTERINTERCHAINACCOUNT._options = None
  _MSGREGISTERINTERCHAINACCOUNT._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGREGISTERINTERCHAINACCOUNTRESPONSE.fields_by_name['channel_id']._options = None
  _MSGREGISTERINTERCHAINACCOUNTRESPONSE.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _MSGREGISTERINTERCHAINACCOUNTRESPONSE.fields_by_name['port_id']._options = None
  _MSGREGISTERINTERCHAINACCOUNTRESPONSE.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _MSGSENDTX.fields_by_name['connection_id']._options = None
  _MSGSENDTX.fields_by_name['connection_id']._serialized_options = b'\362\336\037\024yaml:\"connection_id\"'
  _MSGSENDTX.fields_by_name['packet_data']._options = None
  _MSGSENDTX.fields_by_name['packet_data']._serialized_options = b'\310\336\037\000\362\336\037\022yaml:\"packet_data\"'
  _MSGSENDTX.fields_by_name['relative_timeout']._options = None
  _MSGSENDTX.fields_by_name['relative_timeout']._serialized_options = b'\362\336\037\027yaml:\"relative_timeout\"'
  _MSGSENDTX._options = None
  _MSGSENDTX._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGREGISTERINTERCHAINACCOUNT']._serialized_start=191
  _globals['_MSGREGISTERINTERCHAINACCOUNT']._serialized_end=312
  _globals['_MSGREGISTERINTERCHAINACCOUNTRESPONSE']._serialized_start=314
  _globals['_MSGREGISTERINTERCHAINACCOUNTRESPONSE']._serialized_end=432
  _globals['_MSGSENDTX']._serialized_start=435
  _globals['_MSGSENDTX']._serialized_end=694
  _globals['_MSGSENDTXRESPONSE']._serialized_start=696
  _globals['_MSGSENDTXRESPONSE']._serialized_end=733
  _globals['_MSG']._serialized_start=736
  _globals['_MSG']._serialized_end=1088
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/ocr/v1beta1/genesis.proto\x12\x15injective.ocr.v1beta1\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xed\x04\n\x0cGenesisState\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x37\n\x0c\x66\x65\x65\x64_configs\x18\x02 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedConfig\x12I\n\x17latest_epoch_and_rounds\x18\x03 \x03(\x0b\x32(.injective.ocr.v1beta1.FeedEpochAndRound\x12\x43\n\x12\x66\x65\x65\x64_transmissions\x18\x04 \x03(\x0b\x32\'.injective.ocr.v1beta1.FeedTransmission\x12X\n\x1blatest_aggregator_round_ids\x18\x05 \x03(\x0b\x32\x33.injective.ocr.v1beta1.FeedLatestAggregatorRoundIDs\x12\x37\n\x0creward_pools\x18\x06 \x03(\x0b\x32!.injective.ocr.v1beta1.RewardPool\x12\x42\n\x17\x66\x65\x65\x64_observation_counts\x18\x07 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedCounts\x12\x43\n\x18\x66\x65\x65\x64_transmission_counts\x18\x08 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedCounts\x12\x43\n\x12pending_payeeships\x18\t \x03(\x0b\x32\'.injective.ocr.v1beta1.PendingPayeeship\"^\n\x10\x46\x65\x65\x64Transmission\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x39\n\x0ctransmission\x18\x02 \x01(\x0b\x32#.injective.ocr.v1beta1.Transmission\"c\n\x11\x46\x65\x65\x64\x45pochAndRound\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12=\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\"L\n\x1c\x46\x65\x65\x64LatestAggregatorRoundIDs\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61ggregator_round_id\x18\x02 \x01(\x04\"N\n\nRewardPool\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12/\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"K\n\nFeedCounts\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12,\n\x06\x63ounts\x18\x02 \x03(\x0b\x32\x1c.injective.ocr.v1beta1.Count\"\'\n\x05\x43ount\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"P\n\x10PendingPayeeship\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x13\n\x0btransmitter\x18\x02 \x01(\t\x12\x16\n\x0eproposed_payee\x18\x03 \x01(\tBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.ocr.v1beta1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _REWARDPOOL.fields_by_name['amount']._options = None
  _REWARDPOOL.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=150
  _globals['_GENESISSTATE']._serialized_end=771
  _globals['_FEEDTRANSMISSION']._serialized_start=773
  _globals['_FEEDTRANSMISSION']._serialized_end=867
  _globals['_FEEDEPOCHANDROUND']._serialized_start=869
  _globals['_FEEDEPOCHANDROUND']._serialized_end=968
  _globals['_FEEDLATESTAGGREGATORROUNDIDS']._serialized_start=970
  _globals['_FEEDLATESTAGGREGATORROUNDIDS']._serialized_end=1046
  _globals['_REWARDPOOL']._serialized_start=1048
  _globals['_REWARDPOOL']._serialized_end=1126
  _globals['_FEEDCOUNTS']._serialized_start=1128
  _globals['_FEEDCOUNTS']._serialized_end=1203
  _globals['_COUNT']._serialized_start=1205
  _globals['_COUNT']._serialized_end=1244
  _globals['_PENDINGPAYEESHIP']._serialized_start=1246
  _globals['_PENDINGPAYEESHIP']._serialized_end=1326
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/statesync/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/statesync/types.proto\x12\x14tendermint.statesync\"\x98\x02\n\x07Message\x12\x43\n\x11snapshots_request\x18\x01 \x01(\x0b\x32&.tendermint.statesync.SnapshotsRequestH\x00\x12\x45\n\x12snapshots_response\x18\x02 \x01(\x0b\x32\'.tendermint.statesync.SnapshotsResponseH\x00\x12;\n\rchunk_request\x18\x03 \x01(\x0b\x32\".tendermint.statesync.ChunkRequestH\x00\x12=\n\x0e\x63hunk_response\x18\x04 \x01(\x0b\x32#.tendermint.statesync.ChunkResponseH\x00\x42\x05\n\x03sum\"\x12\n\x10SnapshotsRequest\"c\n\x11SnapshotsResponse\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\x0e\n\x06\x63hunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x10\n\x08metadata\x18\x05 \x01(\x0c\"=\n\x0c\x43hunkRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\r\n\x05index\x18\x03 \x01(\r\"^\n\rChunkResponse\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\r\n\x05index\x18\x03 \x01(\r\x12\r\n\x05\x63hunk\x18\x04 \x01(\x0c\x12\x0f\n\x07missing\x18\x05 \x01(\x08\x42\x39Z7github.com/cometbft/cometbft/proto/tendermint/statesyncb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.statesync.types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/cometbft/cometbft/proto/tendermint/statesync'
  _globals['_MESSAGE']._serialized_start=59
  _globals['_MESSAGE']._serialized_end=339
  _globals['_SNAPSHOTSREQUEST']._serialized_start=341
  _globals['_SNAPSHOTSREQUEST']._serialized_end=359
  _globals['_SNAPSHOTSRESPONSE']._serialized_start=361
  _globals['_SNAPSHOTSRESPONSE']._serialized_end=460
  _globals['_CHUNKREQUEST']._serialized_start=462
  _globals['_CHUNKREQUEST']._serialized_end=523
  _globals['_CHUNKRESPONSE']._serialized_start=525
  _globals['_CHUNKRESPONSE']._serialized_end=619
# @@protoc_insertion_point(module_scope)



import asyncio
import datetime
import time
from abc import ABC, abstractmethod
from http.cookies import SimpleCookie
from typing import Callable, Optional, Tuple


class CookieAssistant(ABC):
    SESSION_RENEWAL_OFFSET = 120

    @abstractmethod
    async def chain_cookie(self, metadata_query_provider: Callable) -> str:
        ...

    @abstractmethod
    async def exchange_cookie(self, metadata_query_provider: Callable) -> str:
        ...

    async def chain_metadata(self, metadata_query_provider: Callable) -> Tuple[Tuple[str, str]]:
        cookie = await self.chain_cookie(metadata_query_provider=metadata_query_provider)
        return (("cookie", cookie),)

    async def exchange_metadata(self, metadata_query_provider: Callable) -> Tuple[Tuple[str, str]]:
        cookie = await self.exchange_cookie(metadata_query_provider=metadata_query_provider)
        return (("cookie", cookie),)


class KubernetesLoadBalancedCookieAssistant(CookieAssistant):
    def __init__(self):
        self._chain_cookie: Optional[str] = None
        self._exchange_cookie: Optional[str] = None
        self._chain_cookie_initialization_lock = asyncio.Lock()
        self._exchange_cookie_initialization_lock = asyncio.Lock()

    async def chain_cookie(self, metadata_query_provider: Callable) -> str:
        if self._chain_cookie is None:
            async with self._chain_cookie_initialization_lock:
                if self._chain_cookie is None:
                    await self._fetch_chain_cookie(metadata_query_provider=metadata_query_provider)
        cookie = self._chain_cookie
        self._check_chain_cookie_expiration()

        return cookie

    async def exchange_cookie(self, metadata_query_provider: Callable) -> str:
        if self._exchange_cookie is None:
            async with self._exchange_cookie_initialization_lock:
                if self._exchange_cookie is None:
                    await self._fetch_exchange_cookie(metadata_query_provider=metadata_query_provider)
        cookie = self._exchange_cookie
        self._check_exchange_cookie_expiration()

        return cookie

    async def _fetch_chain_cookie(self, metadata_query_provider: Callable):
        metadata = await metadata_query_provider()
        cookie_info = next((value for key, value in metadata if key == "set-cookie"), None)

        if cookie_info is None:
            raise RuntimeError(f"Error fetching chain cookie ({metadata})")

        self._chain_cookie = cookie_info

    async def _fetch_exchange_cookie(self, metadata_query_provider: Callable):
        metadata = await metadata_query_provider()
        cookie_info = next((value for key, value in metadata if key == "set-cookie"), None)

        if cookie_info is None:
            raise RuntimeError(f"Error fetching exchange cookie ({metadata})")

        self._exchange_cookie = cookie_info

    def _check_chain_cookie_expiration(self):
        if self._is_cookie_expired(cookie_data=self._chain_cookie):
            self._chain_cookie = None

    def _check_exchange_cookie_expiration(self):
        if self._is_cookie_expired(cookie_data=self._exchange_cookie):
            self._exchange_cookie = None

    def _is_cookie_expired(self, cookie_data: str) -> bool:
        cookie = SimpleCookie()
        cookie.load(cookie_data)

        expiration_time = datetime.datetime.strptime(cookie["GCLB"]["expires"], "%a, %d-%b-%Y %H:%M:%S %Z").timestamp()

        timestamp_diff = expiration_time - time.time()
        return timestamp_diff < self.SESSION_RENEWAL_OFFSET


class BareMetalLoadBalancedCookieAssistant(CookieAssistant):
    def __init__(self):
        self._chain_cookie: Optional[str] = None
        self._exchange_cookie: Optional[str] = None
        self._chain_cookie_initialization_lock = asyncio.Lock()
        self._exchange_cookie_initialization_lock = asyncio.Lock()

    async def chain_cookie(self, metadata_query_provider: Callable) -> str:
        if self._chain_cookie is None:
            async with self._chain_cookie_initialization_lock:
                if self._chain_cookie is None:
                    await self._fetch_chain_cookie(metadata_query_provider=metadata_query_provider)
        cookie = self._chain_cookie
        self._check_chain_cookie_expiration()

        return cookie

    async def exchange_cookie(self, metadata_query_provider: Callable) -> str:
        if self._exchange_cookie is None:
            async with self._exchange_cookie_initialization_lock:
                if self._exchange_cookie is None:
                    await self._fetch_exchange_cookie(metadata_query_provider=metadata_query_provider)
        cookie = self._exchange_cookie
        self._check_exchange_cookie_expiration()

        return cookie

    async def _fetch_chain_cookie(self, metadata_query_provider: Callable):
        metadata = await metadata_query_provider()
        cookie_info = next((value for key, value in metadata if key == "set-cookie"), None)

        if cookie_info is None:
            raise RuntimeError(f"Error fetching chain cookie ({metadata})")

        self._chain_cookie = cookie_info

    async def _fetch_exchange_cookie(self, metadata_query_provider: Callable):
        metadata = await metadata_query_provider()
        cookie_info = next((value for key, value in metadata if key == "set-cookie"), None)

        if cookie_info is None:
            raise RuntimeError(f"Error fetching exchange cookie ({metadata})")

        self._exchange_cookie = cookie_info

    def _check_chain_cookie_expiration(self):
        if self._is_cookie_expired(cookie_data=self._chain_cookie):
            self._chain_cookie = None

    def _check_exchange_cookie_expiration(self):
        if self._is_cookie_expired(cookie_data=self._exchange_cookie):
            self._exchange_cookie = None

    def _is_cookie_expired(self, cookie_data: str) -> bool:
        # The cookies for these nodes do not expire
        return False


class DisabledCookieAssistant(CookieAssistant):
    async def chain_cookie(self, metadata_query_provider: Callable) -> str:
        pass

    async def exchange_cookie(self, metadata_query_provider: Callable) -> str:
        pass

    async def chain_metadata(self, metadata_query_provider: Callable) -> Tuple[Tuple[str, str]]:
        return None

    async def exchange_metadata(self, metadata_query_provider: Callable) -> Tuple[Tuple[str, str]]:
        return None


class Network:
    def __init__(
        self,
        lcd_endpoint: str,
        tm_websocket_endpoint: str,
        grpc_endpoint: str,
        grpc_exchange_endpoint: str,
        grpc_explorer_endpoint: str,
        chain_stream_endpoint: str,
        chain_id: str,
        fee_denom: str,
        env: str,
        cookie_assistant: CookieAssistant,
        use_secure_connection: bool = False,
    ):
        self.lcd_endpoint = lcd_endpoint
        self.tm_websocket_endpoint = tm_websocket_endpoint
        self.grpc_endpoint = grpc_endpoint
        self.grpc_exchange_endpoint = grpc_exchange_endpoint
        self.grpc_explorer_endpoint = grpc_explorer_endpoint
        self.chain_stream_endpoint = chain_stream_endpoint
        self.chain_id = chain_id
        self.fee_denom = fee_denom
        self.env = env
        self.cookie_assistant = cookie_assistant
        self.use_secure_connection = use_secure_connection

    @classmethod
    def devnet(cls):
        return cls(
            lcd_endpoint="https://devnet.lcd.injective.dev",
            tm_websocket_endpoint="wss://devnet.tm.injective.dev/websocket",
            grpc_endpoint="devnet.injective.dev:9900",
            grpc_exchange_endpoint="devnet.injective.dev:9910",
            grpc_explorer_endpoint="devnet.injective.dev:9911",
            chain_stream_endpoint="devnet.injective.dev:9999",
            chain_id="injective-777",
            fee_denom="inj",
            env="devnet",
            cookie_assistant=DisabledCookieAssistant(),
        )

    @classmethod
    def testnet(cls, node="lb"):
        nodes = [
            "lb",
            "sentry",
        ]
        if node not in nodes:
            raise ValueError("Must be one of {}".format(nodes))

        if node == "lb":
            lcd_endpoint = "https://testnet.sentry.lcd.injective.network:443"
            tm_websocket_endpoint = "wss://testnet.sentry.tm.injective.network:443/websocket"
            grpc_endpoint = "testnet.sentry.chain.grpc.injective.network:443"
            grpc_exchange_endpoint = "testnet.sentry.exchange.grpc.injective.network:443"
            grpc_explorer_endpoint = "testnet.sentry.explorer.grpc.injective.network:443"
            chain_stream_endpoint = "testnet.sentry.chain.stream.injective.network:443"
            cookie_assistant = BareMetalLoadBalancedCookieAssistant()
            use_secure_connection = True
        else:
            lcd_endpoint = "https://testnet.lcd.injective.network:443"
            tm_websocket_endpoint = "wss://testnet.tm.injective.network:443/websocket"
            grpc_endpoint = "testnet.chain.grpc.injective.network:443"
            grpc_exchange_endpoint = "testnet.exchange.grpc.injective.network:443"
            grpc_explorer_endpoint = "testnet.explorer.grpc.injective.network:443"
            chain_stream_endpoint = "testnet.chain.stream.injective.network:443"
            cookie_assistant = DisabledCookieAssistant()
            use_secure_connection = True

        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_stream_endpoint=chain_stream_endpoint,
            chain_id="injective-888",
            fee_denom="inj",
            env="testnet",
            cookie_assistant=cookie_assistant,
            use_secure_connection=use_secure_connection,
        )

    @classmethod
    def mainnet(cls, node="lb"):
        nodes = [
            "lb",
        ]
        if node not in nodes:
            raise ValueError("Must be one of {}".format(nodes))

        lcd_endpoint = "https://sentry.lcd.injective.network:443"
        tm_websocket_endpoint = "wss://sentry.tm.injective.network:443/websocket"
        grpc_endpoint = "sentry.chain.grpc.injective.network:443"
        grpc_exchange_endpoint = "sentry.exchange.grpc.injective.network:443"
        grpc_explorer_endpoint = "sentry.explorer.grpc.injective.network:443"
        chain_stream_endpoint = "sentry.chain.stream.injective.network:443"
        cookie_assistant = BareMetalLoadBalancedCookieAssistant()
        use_secure_connection = True

        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_stream_endpoint=chain_stream_endpoint,
            chain_id="injective-1",
            fee_denom="inj",
            env="mainnet",
            cookie_assistant=cookie_assistant,
            use_secure_connection=use_secure_connection,
        )

    @classmethod
    def local(cls):
        return cls(
            lcd_endpoint="http://localhost:10337",
            tm_websocket_endpoint="ws://localhost:26657/websocket",
            grpc_endpoint="localhost:9900",
            grpc_exchange_endpoint="localhost:9910",
            grpc_explorer_endpoint="localhost:9911",
            chain_stream_endpoint="localhost:9999",
            chain_id="injective-1",
            fee_denom="inj",
            env="local",
            cookie_assistant=DisabledCookieAssistant(),
            use_secure_connection=False,
        )

    @classmethod
    def custom(
        cls,
        lcd_endpoint,
        tm_websocket_endpoint,
        grpc_endpoint,
        grpc_exchange_endpoint,
        grpc_explorer_endpoint,
        chain_stream_endpoint,
        chain_id,
        env,
        cookie_assistant: Optional[CookieAssistant] = None,
        use_secure_connection: bool = False,
    ):
        assistant = cookie_assistant or DisabledCookieAssistant()
        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_stream_endpoint=chain_stream_endpoint,
            chain_id=chain_id,
            fee_denom="inj",
            env=env,
            cookie_assistant=assistant,
            use_secure_connection=use_secure_connection,
        )

    def string(self):
        return self.env

    async def chain_metadata(self, metadata_query_provider: Callable) -> Tuple[Tuple[str, str]]:
        return await self.cookie_assistant.chain_metadata(metadata_query_provider=metadata_query_provider)

    async def exchange_metadata(self, metadata_query_provider: Callable) -> Tuple[Tuple[str, str]]:
        return await self.cookie_assistant.exchange_metadata(metadata_query_provider=metadata_query_provider)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_spot_exchange_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*exchange/injective_spot_exchange_rpc.proto\x12\x1binjective_spot_exchange_rpc\"i\n\x0eMarketsRequest\x12\x15\n\rmarket_status\x18\x01 \x01(\t\x12\x12\n\nbase_denom\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x17\n\x0fmarket_statuses\x18\x04 \x03(\t\"O\n\x0fMarketsResponse\x12<\n\x07markets\x18\x01 \x03(\x0b\x32+.injective_spot_exchange_rpc.SpotMarketInfo\"\x81\x03\n\x0eSpotMarketInfo\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rmarket_status\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x12\n\nbase_denom\x18\x04 \x01(\t\x12?\n\x0f\x62\x61se_token_meta\x18\x05 \x01(\x0b\x32&.injective_spot_exchange_rpc.TokenMeta\x12\x13\n\x0bquote_denom\x18\x06 \x01(\t\x12@\n\x10quote_token_meta\x18\x07 \x01(\x0b\x32&.injective_spot_exchange_rpc.TokenMeta\x12\x16\n\x0emaker_fee_rate\x18\x08 \x01(\t\x12\x16\n\x0etaker_fee_rate\x18\t \x01(\t\x12\x1c\n\x14service_provider_fee\x18\n \x01(\t\x12\x1b\n\x13min_price_tick_size\x18\x0b \x01(\t\x12\x1e\n\x16min_quantity_tick_size\x18\x0c \x01(\t\"n\n\tTokenMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x05 \x01(\x11\x12\x12\n\nupdated_at\x18\x06 \x01(\x12\"\"\n\rMarketRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"M\n\x0eMarketResponse\x12;\n\x06market\x18\x01 \x01(\x0b\x32+.injective_spot_exchange_rpc.SpotMarketInfo\"*\n\x14StreamMarketsRequest\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"\x7f\n\x15StreamMarketsResponse\x12;\n\x06market\x18\x01 \x01(\x0b\x32+.injective_spot_exchange_rpc.SpotMarketInfo\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"\'\n\x12OrderbookV2Request\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"[\n\x13OrderbookV2Response\x12\x44\n\torderbook\x18\x01 \x01(\x0b\x32\x31.injective_spot_exchange_rpc.SpotLimitOrderbookV2\"\xaa\x01\n\x14SpotLimitOrderbookV2\x12\x35\n\x04\x62uys\x18\x01 \x03(\x0b\x32\'.injective_spot_exchange_rpc.PriceLevel\x12\x36\n\x05sells\x18\x02 \x03(\x0b\x32\'.injective_spot_exchange_rpc.PriceLevel\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x12\x11\n\ttimestamp\x18\x04 \x01(\x12\"@\n\nPriceLevel\x12\r\n\x05price\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\")\n\x13OrderbooksV2Request\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"c\n\x14OrderbooksV2Response\x12K\n\norderbooks\x18\x01 \x03(\x0b\x32\x37.injective_spot_exchange_rpc.SingleSpotLimitOrderbookV2\"u\n\x1aSingleSpotLimitOrderbookV2\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x44\n\torderbook\x18\x02 \x01(\x0b\x32\x31.injective_spot_exchange_rpc.SpotLimitOrderbookV2\".\n\x18StreamOrderbookV2Request\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"\x9f\x01\n\x19StreamOrderbookV2Response\x12\x44\n\torderbook\x18\x01 \x01(\x0b\x32\x31.injective_spot_exchange_rpc.SpotLimitOrderbookV2\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\x12\x11\n\tmarket_id\x18\x04 \x01(\t\"2\n\x1cStreamOrderbookUpdateRequest\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"\xb2\x01\n\x1dStreamOrderbookUpdateResponse\x12S\n\x17orderbook_level_updates\x18\x01 \x01(\x0b\x32\x32.injective_spot_exchange_rpc.OrderbookLevelUpdates\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\x12\x11\n\tmarket_id\x18\x04 \x01(\t\"\xcb\x01\n\x15OrderbookLevelUpdates\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x04\x12;\n\x04\x62uys\x18\x03 \x03(\x0b\x32-.injective_spot_exchange_rpc.PriceLevelUpdate\x12<\n\x05sells\x18\x04 \x03(\x0b\x32-.injective_spot_exchange_rpc.PriceLevelUpdate\x12\x12\n\nupdated_at\x18\x05 \x01(\x12\"Y\n\x10PriceLevelUpdate\x12\r\n\x05price\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x11\n\ttimestamp\x18\x04 \x01(\x12\"\xfe\x01\n\rOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x12\n\norder_side\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x0c\n\x04skip\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\x11\x12\x12\n\nstart_time\x18\x06 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x07 \x01(\x12\x12\x12\n\nmarket_ids\x18\x08 \x03(\t\x12\x18\n\x10include_inactive\x18\t \x01(\x08\x12\x1f\n\x17subaccount_total_orders\x18\n \x01(\x08\x12\x10\n\x08trade_id\x18\x0b \x01(\t\x12\x0b\n\x03\x63id\x18\x0c \x01(\t\"\x82\x01\n\x0eOrdersResponse\x12;\n\x06orders\x18\x01 \x03(\x0b\x32+.injective_spot_exchange_rpc.SpotLimitOrder\x12\x33\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.Paging\"\xa1\x02\n\x0eSpotLimitOrder\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x12\n\norder_side\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\x12\x10\n\x08quantity\x18\x06 \x01(\t\x12\x19\n\x11unfilled_quantity\x18\x07 \x01(\t\x12\x15\n\rtrigger_price\x18\x08 \x01(\t\x12\x15\n\rfee_recipient\x18\t \x01(\t\x12\r\n\x05state\x18\n \x01(\t\x12\x12\n\ncreated_at\x18\x0b \x01(\x12\x12\x12\n\nupdated_at\x18\x0c \x01(\x12\x12\x0f\n\x07tx_hash\x18\r \x01(\t\x12\x0b\n\x03\x63id\x18\x0e \x01(\t\"\\\n\x06Paging\x12\r\n\x05total\x18\x01 \x01(\x12\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x11\x12\n\n\x02to\x18\x03 \x01(\x11\x12\x1b\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12\x12\x0c\n\x04next\x18\x05 \x03(\t\"\x84\x02\n\x13StreamOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x12\n\norder_side\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x0c\n\x04skip\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\x11\x12\x12\n\nstart_time\x18\x06 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x07 \x01(\x12\x12\x12\n\nmarket_ids\x18\x08 \x03(\t\x12\x18\n\x10include_inactive\x18\t \x01(\x08\x12\x1f\n\x17subaccount_total_orders\x18\n \x01(\x08\x12\x10\n\x08trade_id\x18\x0b \x01(\t\x12\x0b\n\x03\x63id\x18\x0c \x01(\t\"}\n\x14StreamOrdersResponse\x12:\n\x05order\x18\x01 \x01(\x0b\x32+.injective_spot_exchange_rpc.SpotLimitOrder\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"\xa4\x02\n\rTradesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xecution_side\x18\x02 \x01(\t\x12\x11\n\tdirection\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\r\n\x05limit\x18\x06 \x01(\x11\x12\x12\n\nstart_time\x18\x07 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x08 \x01(\x12\x12\x12\n\nmarket_ids\x18\t \x03(\t\x12\x16\n\x0esubaccount_ids\x18\n \x03(\t\x12\x17\n\x0f\x65xecution_types\x18\x0b \x03(\t\x12\x10\n\x08trade_id\x18\x0c \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\r \x01(\t\x12\x0b\n\x03\x63id\x18\x0e \x01(\t\"}\n\x0eTradesResponse\x12\x36\n\x06trades\x18\x01 \x03(\x0b\x32&.injective_spot_exchange_rpc.SpotTrade\x12\x33\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.Paging\"\xa8\x02\n\tSpotTrade\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x1c\n\x14trade_execution_type\x18\x04 \x01(\t\x12\x17\n\x0ftrade_direction\x18\x05 \x01(\t\x12\x36\n\x05price\x18\x06 \x01(\x0b\x32\'.injective_spot_exchange_rpc.PriceLevel\x12\x0b\n\x03\x66\x65\x65\x18\x07 \x01(\t\x12\x13\n\x0b\x65xecuted_at\x18\x08 \x01(\x12\x12\x15\n\rfee_recipient\x18\t \x01(\t\x12\x10\n\x08trade_id\x18\n \x01(\t\x12\x16\n\x0e\x65xecution_side\x18\x0b \x01(\t\x12\x0b\n\x03\x63id\x18\x0c \x01(\t\"\xaa\x02\n\x13StreamTradesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xecution_side\x18\x02 \x01(\t\x12\x11\n\tdirection\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\r\n\x05limit\x18\x06 \x01(\x11\x12\x12\n\nstart_time\x18\x07 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x08 \x01(\x12\x12\x12\n\nmarket_ids\x18\t \x03(\t\x12\x16\n\x0esubaccount_ids\x18\n \x03(\t\x12\x17\n\x0f\x65xecution_types\x18\x0b \x03(\t\x12\x10\n\x08trade_id\x18\x0c \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\r \x01(\t\x12\x0b\n\x03\x63id\x18\x0e \x01(\t\"x\n\x14StreamTradesResponse\x12\x35\n\x05trade\x18\x01 \x01(\x0b\x32&.injective_spot_exchange_rpc.SpotTrade\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"d\n\x1bSubaccountOrdersListRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x0c\n\x04skip\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x11\"\x90\x01\n\x1cSubaccountOrdersListResponse\x12;\n\x06orders\x18\x01 \x03(\x0b\x32+.injective_spot_exchange_rpc.SpotLimitOrder\x12\x33\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.Paging\"\x8f\x01\n\x1bSubaccountTradesListRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x16\n\x0e\x65xecution_type\x18\x03 \x01(\t\x12\x11\n\tdirection\x18\x04 \x01(\t\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\r\n\x05limit\x18\x06 \x01(\x11\"V\n\x1cSubaccountTradesListResponse\x12\x36\n\x06trades\x18\x01 \x03(\x0b\x32&.injective_spot_exchange_rpc.SpotTrade\"\xa3\x02\n\x14OrdersHistoryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x0c\n\x04skip\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x11\x12\x13\n\x0border_types\x18\x05 \x03(\t\x12\x11\n\tdirection\x18\x06 \x01(\t\x12\x12\n\nstart_time\x18\x07 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x08 \x01(\x12\x12\r\n\x05state\x18\t \x01(\t\x12\x17\n\x0f\x65xecution_types\x18\n \x03(\t\x12\x12\n\nmarket_ids\x18\x0b \x03(\t\x12\x10\n\x08trade_id\x18\x0c \x01(\t\x12\x1b\n\x13\x61\x63tive_markets_only\x18\r \x01(\x08\x12\x0b\n\x03\x63id\x18\x0e \x01(\t\"\x8b\x01\n\x15OrdersHistoryResponse\x12=\n\x06orders\x18\x01 \x03(\x0b\x32-.injective_spot_exchange_rpc.SpotOrderHistory\x12\x33\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.Paging\"\xc8\x02\n\x10SpotOrderHistory\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\x16\n\x0e\x65xecution_type\x18\x05 \x01(\t\x12\x12\n\norder_type\x18\x06 \x01(\t\x12\r\n\x05price\x18\x07 \x01(\t\x12\x15\n\rtrigger_price\x18\x08 \x01(\t\x12\x10\n\x08quantity\x18\t \x01(\t\x12\x17\n\x0f\x66illed_quantity\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x0c \x01(\x12\x12\x12\n\nupdated_at\x18\r \x01(\x12\x12\x11\n\tdirection\x18\x0e \x01(\t\x12\x0f\n\x07tx_hash\x18\x0f \x01(\t\x12\x0b\n\x03\x63id\x18\x10 \x01(\t\"\x96\x01\n\x1aStreamOrdersHistoryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x13\n\x0border_types\x18\x03 \x03(\t\x12\x11\n\tdirection\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\x12\x17\n\x0f\x65xecution_types\x18\x06 \x03(\t\"\x86\x01\n\x1bStreamOrdersHistoryResponse\x12<\n\x05order\x18\x01 \x01(\x0b\x32-.injective_spot_exchange_rpc.SpotOrderHistory\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"\x8a\x01\n\x18\x41tomicSwapHistoryRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\x12\x0c\n\x04skip\x18\x03 \x01(\x11\x12\r\n\x05limit\x18\x04 \x01(\x11\x12\x13\n\x0b\x66rom_number\x18\x05 \x01(\x11\x12\x11\n\tto_number\x18\x06 \x01(\x11\"\x87\x01\n\x19\x41tomicSwapHistoryResponse\x12\x33\n\x06paging\x18\x01 \x01(\x0b\x32#.injective_spot_exchange_rpc.Paging\x12\x35\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\'.injective_spot_exchange_rpc.AtomicSwap\"\xdc\x02\n\nAtomicSwap\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\r\n\x05route\x18\x02 \x01(\t\x12\x36\n\x0bsource_coin\x18\x03 \x01(\x0b\x32!.injective_spot_exchange_rpc.Coin\x12\x34\n\tdest_coin\x18\x04 \x01(\x0b\x32!.injective_spot_exchange_rpc.Coin\x12/\n\x04\x66\x65\x65s\x18\x05 \x03(\x0b\x32!.injective_spot_exchange_rpc.Coin\x12\x18\n\x10\x63ontract_address\x18\x06 \x01(\t\x12\x17\n\x0findex_by_sender\x18\x07 \x01(\x11\x12 \n\x18index_by_sender_contract\x18\x08 \x01(\x11\x12\x0f\n\x07tx_hash\x18\t \x01(\t\x12\x13\n\x0b\x65xecuted_at\x18\n \x01(\x12\x12\x15\n\rrefund_amount\x18\x0b \x01(\t\"%\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t2\xb8\x0f\n\x18InjectiveSpotExchangeRPC\x12\x64\n\x07Markets\x12+.injective_spot_exchange_rpc.MarketsRequest\x1a,.injective_spot_exchange_rpc.MarketsResponse\x12\x61\n\x06Market\x12*.injective_spot_exchange_rpc.MarketRequest\x1a+.injective_spot_exchange_rpc.MarketResponse\x12x\n\rStreamMarkets\x12\x31.injective_spot_exchange_rpc.StreamMarketsRequest\x1a\x32.injective_spot_exchange_rpc.StreamMarketsResponse0\x01\x12p\n\x0bOrderbookV2\x12/.injective_spot_exchange_rpc.OrderbookV2Request\x1a\x30.injective_spot_exchange_rpc.OrderbookV2Response\x12s\n\x0cOrderbooksV2\x12\x30.injective_spot_exchange_rpc.OrderbooksV2Request\x1a\x31.injective_spot_exchange_rpc.OrderbooksV2Response\x12\x84\x01\n\x11StreamOrderbookV2\x12\x35.injective_spot_exchange_rpc.StreamOrderbookV2Request\x1a\x36.injective_spot_exchange_rpc.StreamOrderbookV2Response0\x01\x12\x90\x01\n\x15StreamOrderbookUpdate\x12\x39.injective_spot_exchange_rpc.StreamOrderbookUpdateRequest\x1a:.injective_spot_exchange_rpc.StreamOrderbookUpdateResponse0\x01\x12\x61\n\x06Orders\x12*.injective_spot_exchange_rpc.OrdersRequest\x1a+.injective_spot_exchange_rpc.OrdersResponse\x12u\n\x0cStreamOrders\x12\x30.injective_spot_exchange_rpc.StreamOrdersRequest\x1a\x31.injective_spot_exchange_rpc.StreamOrdersResponse0\x01\x12\x61\n\x06Trades\x12*.injective_spot_exchange_rpc.TradesRequest\x1a+.injective_spot_exchange_rpc.TradesResponse\x12u\n\x0cStreamTrades\x12\x30.injective_spot_exchange_rpc.StreamTradesRequest\x1a\x31.injective_spot_exchange_rpc.StreamTradesResponse0\x01\x12\x8b\x01\n\x14SubaccountOrdersList\x12\x38.injective_spot_exchange_rpc.SubaccountOrdersListRequest\x1a\x39.injective_spot_exchange_rpc.SubaccountOrdersListResponse\x12\x8b\x01\n\x14SubaccountTradesList\x12\x38.injective_spot_exchange_rpc.SubaccountTradesListRequest\x1a\x39.injective_spot_exchange_rpc.SubaccountTradesListResponse\x12v\n\rOrdersHistory\x12\x31.injective_spot_exchange_rpc.OrdersHistoryRequest\x1a\x32.injective_spot_exchange_rpc.OrdersHistoryResponse\x12\x8a\x01\n\x13StreamOrdersHistory\x12\x37.injective_spot_exchange_rpc.StreamOrdersHistoryRequest\x1a\x38.injective_spot_exchange_rpc.StreamOrdersHistoryResponse0\x01\x12\x82\x01\n\x11\x41tomicSwapHistory\x12\x35.injective_spot_exchange_rpc.AtomicSwapHistoryRequest\x1a\x36.injective_spot_exchange_rpc.AtomicSwapHistoryResponseB Z\x1e/injective_spot_exchange_rpcpbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_spot_exchange_rpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\036/injective_spot_exchange_rpcpb'
  _globals['_MARKETSREQUEST']._serialized_start=75
  _globals['_MARKETSREQUEST']._serialized_end=180
  _globals['_MARKETSRESPONSE']._serialized_start=182
  _globals['_MARKETSRESPONSE']._serialized_end=261
  _globals['_SPOTMARKETINFO']._serialized_start=264
  _globals['_SPOTMARKETINFO']._serialized_end=649
  _globals['_TOKENMETA']._serialized_start=651
  _globals['_TOKENMETA']._serialized_end=761
  _globals['_MARKETREQUEST']._serialized_start=763
  _globals['_MARKETREQUEST']._serialized_end=797
  _globals['_MARKETRESPONSE']._serialized_start=799
  _globals['_MARKETRESPONSE']._serialized_end=876
  _globals['_STREAMMARKETSREQUEST']._serialized_start=878
  _globals['_STREAMMARKETSREQUEST']._serialized_end=920
  _globals['_STREAMMARKETSRESPONSE']._serialized_start=922
  _globals['_STREAMMARKETSRESPONSE']._serialized_end=1049
  _globals['_ORDERBOOKV2REQUEST']._serialized_start=1051
  _globals['_ORDERBOOKV2REQUEST']._serialized_end=1090
  _globals['_ORDERBOOKV2RESPONSE']._serialized_start=1092
  _globals['_ORDERBOOKV2RESPONSE']._serialized_end=1183
  _globals['_SPOTLIMITORDERBOOKV2']._serialized_start=1186
  _globals['_SPOTLIMITORDERBOOKV2']._serialized_end=1356
  _globals['_PRICELEVEL']._serialized_start=1358
  _globals['_PRICELEVEL']._serialized_end=1422
  _globals['_ORDERBOOKSV2REQUEST']._serialized_start=1424
  _globals['_ORDERBOOKSV2REQUEST']._serialized_end=1465
  _globals['_ORDERBOOKSV2RESPONSE']._serialized_start=1467
  _globals['_ORDERBOOKSV2RESPONSE']._serialized_end=1566
  _globals['_SINGLESPOTLIMITORDERBOOKV2']._serialized_start=1568
  _globals['_SINGLESPOTLIMITORDERBOOKV2']._serialized_end=1685
  _globals['_STREAMORDERBOOKV2REQUEST']._serialized_start=1687
  _globals['_STREAMORDERBOOKV2REQUEST']._serialized_end=1733
  _globals['_STREAMORDERBOOKV2RESPONSE']._serialized_start=1736
  _globals['_STREAMORDERBOOKV2RESPONSE']._serialized_end=1895
  _globals['_STREAMORDERBOOKUPDATEREQUEST']._serialized_start=1897
  _globals['_STREAMORDERBOOKUPDATEREQUEST']._serialized_end=1947
  _globals['_STREAMORDERBOOKUPDATERESPONSE']._serialized_start=1950
  _globals['_STREAMORDERBOOKUPDATERESPONSE']._serialized_end=2128
  _globals['_ORDERBOOKLEVELUPDATES']._serialized_start=2131
  _globals['_ORDERBOOKLEVELUPDATES']._serialized_end=2334
  _globals['_PRICELEVELUPDATE']._serialized_start=2336
  _globals['_PRICELEVELUPDATE']._serialized_end=2425
  _globals['_ORDERSREQUEST']._serialized_start=2428
  _globals['_ORDERSREQUEST']._serialized_end=2682
  _globals['_ORDERSRESPONSE']._serialized_start=2685
  _globals['_ORDERSRESPONSE']._serialized_end=2815
  _globals['_SPOTLIMITORDER']._serialized_start=2818
  _globals['_SPOTLIMITORDER']._serialized_end=3107
  _globals['_PAGING']._serialized_start=3109
  _globals['_PAGING']._serialized_end=3201
  _globals['_STREAMORDERSREQUEST']._serialized_start=3204
  _globals['_STREAMORDERSREQUEST']._serialized_end=3464
  _globals['_STREAMORDERSRESPONSE']._serialized_start=3466
  _globals['_STREAMORDERSRESPONSE']._serialized_end=3591
  _globals['_TRADESREQUEST']._serialized_start=3594
  _globals['_TRADESREQUEST']._serialized_end=3886
  _globals['_TRADESRESPONSE']._serialized_start=3888
  _globals['_TRADESRESPONSE']._serialized_end=4013
  _globals['_SPOTTRADE']._serialized_start=4016
  _globals['_SPOTTRADE']._serialized_end=4312
  _globals['_STREAMTRADESREQUEST']._serialized_start=4315
  _globals['_STREAMTRADESREQUEST']._serialized_end=4613
  _globals['_STREAMTRADESRESPONSE']._serialized_start=4615
  _globals['_STREAMTRADESRESPONSE']._serialized_end=4735
  _globals['_SUBACCOUNTORDERSLISTREQUEST']._serialized_start=4737
  _globals['_SUBACCOUNTORDERSLISTREQUEST']._serialized_end=4837
  _globals['_SUBACCOUNTORDERSLISTRESPONSE']._serialized_start=4840
  _globals['_SUBACCOUNTORDERSLISTRESPONSE']._serialized_end=4984
  _globals['_SUBACCOUNTTRADESLISTREQUEST']._serialized_start=4987
  _globals['_SUBACCOUNTTRADESLISTREQUEST']._serialized_end=5130
  _globals['_SUBACCOUNTTRADESLISTRESPONSE']._serialized_start=5132
  _globals['_SUBACCOUNTTRADESLISTRESPONSE']._serialized_end=5218
  _globals['_ORDERSHISTORYREQUEST']._serialized_start=5221
  _globals['_ORDERSHISTORYREQUEST']._serialized_end=5512
  _globals['_ORDERSHISTORYRESPONSE']._serialized_start=5515
  _globals['_ORDERSHISTORYRESPONSE']._serialized_end=5654
  _globals['_SPOTORDERHISTORY']._serialized_start=5657
  _globals['_SPOTORDERHISTORY']._serialized_end=5985
  _globals['_STREAMORDERSHISTORYREQUEST']._serialized_start=5988
  _globals['_STREAMORDERSHISTORYREQUEST']._serialized_end=6138
  _globals['_STREAMORDERSHISTORYRESPONSE']._serialized_start=6141
  _globals['_STREAMORDERSHISTORYRESPONSE']._serialized_end=6275
  _globals['_ATOMICSWAPHISTORYREQUEST']._serialized_start=6278
  _globals['_ATOMICSWAPHISTORYREQUEST']._serialized_end=6416
  _globals['_ATOMICSWAPHISTORYRESPONSE']._serialized_start=6419
  _globals['_ATOMICSWAPHISTORYRESPONSE']._serialized_end=6554
  _globals['_ATOMICSWAP']._serialized_start=6557
  _globals['_ATOMICSWAP']._serialized_end=6905
  _globals['_COIN']._serialized_start=6907
  _globals['_COIN']._serialized_end=6944
  _globals['_INJECTIVESPOTEXCHANGERPC']._serialized_start=6947
  _globals['_INJECTIVESPOTEXCHANGERPC']._serialized_end=8923
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_auction_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$exchange/injective_auction_rpc.proto\x12\x15injective_auction_rpc\"\'\n\x16\x41uctionEndpointRequest\x12\r\n\x05round\x18\x01 \x01(\x12\"t\n\x17\x41uctionEndpointResponse\x12/\n\x07\x61uction\x18\x01 \x01(\x0b\x32\x1e.injective_auction_rpc.Auction\x12(\n\x04\x62ids\x18\x02 \x03(\x0b\x32\x1a.injective_auction_rpc.Bid\"\x9c\x01\n\x07\x41uction\x12\x0e\n\x06winner\x18\x01 \x01(\t\x12+\n\x06\x62\x61sket\x18\x02 \x03(\x0b\x32\x1b.injective_auction_rpc.Coin\x12\x1a\n\x12winning_bid_amount\x18\x03 \x01(\t\x12\r\n\x05round\x18\x04 \x01(\x04\x12\x15\n\rend_timestamp\x18\x05 \x01(\x12\x12\x12\n\nupdated_at\x18\x06 \x01(\x12\"%\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"8\n\x03\x42id\x12\x0e\n\x06\x62idder\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"\x11\n\x0f\x41uctionsRequest\"D\n\x10\x41uctionsResponse\x12\x30\n\x08\x61uctions\x18\x01 \x03(\x0b\x32\x1e.injective_auction_rpc.Auction\"\x13\n\x11StreamBidsRequest\"Z\n\x12StreamBidsResponse\x12\x0e\n\x06\x62idder\x18\x01 \x01(\t\x12\x12\n\nbid_amount\x18\x02 \x01(\t\x12\r\n\x05round\x18\x03 \x01(\x04\x12\x11\n\ttimestamp\x18\x04 \x01(\x12\x32\xc9\x02\n\x13InjectiveAuctionRPC\x12p\n\x0f\x41uctionEndpoint\x12-.injective_auction_rpc.AuctionEndpointRequest\x1a..injective_auction_rpc.AuctionEndpointResponse\x12[\n\x08\x41uctions\x12&.injective_auction_rpc.AuctionsRequest\x1a\'.injective_auction_rpc.AuctionsResponse\x12\x63\n\nStreamBids\x12(.injective_auction_rpc.StreamBidsRequest\x1a).injective_auction_rpc.StreamBidsResponse0\x01\x42\x1aZ\x18/injective_auction_rpcpbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_auction_rpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\030/injective_auction_rpcpb'
  _globals['_AUCTIONENDPOINTREQUEST']._serialized_start=63
  _globals['_AUCTIONENDPOINTREQUEST']._serialized_end=102
  _globals['_AUCTIONENDPOINTRESPONSE']._serialized_start=104
  _globals['_AUCTIONENDPOINTRESPONSE']._serialized_end=220
  _globals['_AUCTION']._serialized_start=223
  _globals['_AUCTION']._serialized_end=379
  _globals['_COIN']._serialized_start=381
  _globals['_COIN']._serialized_end=418
  _globals['_BID']._serialized_start=420
  _globals['_BID']._serialized_end=476
  _globals['_AUCTIONSREQUEST']._serialized_start=478
  _globals['_AUCTIONSREQUEST']._serialized_end=495
  _globals['_AUCTIONSRESPONSE']._serialized_start=497
  _globals['_AUCTIONSRESPONSE']._serialized_end=565
  _globals['_STREAMBIDSREQUEST']._serialized_start=567
  _globals['_STREAMBIDSREQUEST']._serialized_end=586
  _globals['_STREAMBIDSRESPONSE']._serialized_start=588
  _globals['_STREAMBIDSRESPONSE']._serialized_end=678
  _globals['_INJECTIVEAUCTIONRPC']._serialized_start=681
  _globals['_INJECTIVEAUCTIONRPC']._serialized_end=1010
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/proposal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmwasm/wasm/v1/proposal.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x11\x61mino/amino.proto\"\xc2\x02\n\x11StoreCodeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06run_as\x18\x03 \x01(\t\x12(\n\x0ewasm_byte_code\x18\x04 \x01(\x0c\x42\x10\xe2\xde\x1f\x0cWASMByteCode\x12>\n\x16instantiate_permission\x18\x07 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfig\x12\x12\n\nunpin_code\x18\x08 \x01(\x08\x12\x0e\n\x06source\x18\t \x01(\t\x12\x0f\n\x07\x62uilder\x18\n \x01(\t\x12\x11\n\tcode_hash\x18\x0b \x01(\x0c:;\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x16wasm/StoreCodeProposalJ\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"\xd9\x02\n\x1bInstantiateContractProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06run_as\x18\x03 \x01(\t\x12\r\n\x05\x61\x64min\x18\x04 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x05 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\r\n\x05label\x18\x06 \x01(\t\x12#\n\x03msg\x18\x07 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\x08 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01:E\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0* wasm/InstantiateContractProposal\"\xfa\x02\n\x1cInstantiateContract2Proposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06run_as\x18\x03 \x01(\t\x12\r\n\x05\x61\x64min\x18\x04 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x05 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\r\n\x05label\x18\x06 \x01(\t\x12#\n\x03msg\x18\x07 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\x08 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01\x12\x0c\n\x04salt\x18\t \x01(\x0c\x12\x0f\n\x07\x66ix_msg\x18\n \x01(\x08:F\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*!wasm/InstantiateContract2Proposal\"\xd4\x01\n\x17MigrateContractProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x63ontract\x18\x04 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x05 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12#\n\x03msg\x18\x06 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage:A\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x1cwasm/MigrateContractProposal\"\xb1\x01\n\x14SudoContractProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x63ontract\x18\x03 \x01(\t\x12#\n\x03msg\x18\x04 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage:>\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x19wasm/SudoContractProposal\"\xa8\x02\n\x17\x45xecuteContractProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06run_as\x18\x03 \x01(\t\x12\x10\n\x08\x63ontract\x18\x04 \x01(\t\x12#\n\x03msg\x18\x05 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01:A\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x1cwasm/ExecuteContractProposal\"\xb3\x01\n\x13UpdateAdminProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\'\n\tnew_admin\x18\x03 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"new_admin\"\x12\x10\n\x08\x63ontract\x18\x04 \x01(\t:=\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x18wasm/UpdateAdminProposal\"\x88\x01\n\x12\x43learAdminProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x63ontract\x18\x03 \x01(\t:<\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x17wasm/ClearAdminProposal\"\xce\x01\n\x10PinCodesProposal\x12\x1f\n\x05title\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"title\"\x12+\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"description\"\x12\x30\n\x08\x63ode_ids\x18\x03 \x03(\x04\x42\x1e\xe2\xde\x1f\x07\x43odeIDs\xf2\xde\x1f\x0fyaml:\"code_ids\"::\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x15wasm/PinCodesProposal\"\xd2\x01\n\x12UnpinCodesProposal\x12\x1f\n\x05title\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"title\"\x12+\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"description\"\x12\x30\n\x08\x63ode_ids\x18\x03 \x03(\x04\x42\x1e\xe2\xde\x1f\x07\x43odeIDs\xf2\xde\x1f\x0fyaml:\"code_ids\":<\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x17wasm/UnpinCodesProposal\"|\n\x12\x41\x63\x63\x65ssConfigUpdate\x12\x1b\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12I\n\x16instantiate_permission\x18\x02 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x8a\x02\n\x1fUpdateInstantiateConfigProposal\x12\x1f\n\x05title\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"title\"\x12+\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"description\"\x12N\n\x15\x61\x63\x63\x65ss_config_updates\x18\x03 \x03(\x0b\x32$.cosmwasm.wasm.v1.AccessConfigUpdateB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:I\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*$wasm/UpdateInstantiateConfigProposal\"\xfe\x03\n#StoreAndInstantiateContractProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06run_as\x18\x03 \x01(\t\x12(\n\x0ewasm_byte_code\x18\x04 \x01(\x0c\x42\x10\xe2\xde\x1f\x0cWASMByteCode\x12>\n\x16instantiate_permission\x18\x05 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfig\x12\x12\n\nunpin_code\x18\x06 \x01(\x08\x12\r\n\x05\x61\x64min\x18\x07 \x01(\t\x12\r\n\x05label\x18\x08 \x01(\t\x12#\n\x03msg\x18\t \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12_\n\x05\x66unds\x18\n \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x0f\n\x07\x62uilder\x18\x0c \x01(\t\x12\x11\n\tcode_hash\x18\r \x01(\x0c:M\x18\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*(wasm/StoreAndInstantiateContractProposalB4Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\xd8\xe1\x1e\x00\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.proposal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000\330\341\036\000\250\342\036\001'
  _STORECODEPROPOSAL.fields_by_name['wasm_byte_code']._options = None
  _STORECODEPROPOSAL.fields_by_name['wasm_byte_code']._serialized_options = b'\342\336\037\014WASMByteCode'
  _STORECODEPROPOSAL._options = None
  _STORECODEPROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\026wasm/StoreCodeProposal'
  _INSTANTIATECONTRACTPROPOSAL.fields_by_name['code_id']._options = None
  _INSTANTIATECONTRACTPROPOSAL.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _INSTANTIATECONTRACTPROPOSAL.fields_by_name['msg']._options = None
  _INSTANTIATECONTRACTPROPOSAL.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _INSTANTIATECONTRACTPROPOSAL.fields_by_name['funds']._options = None
  _INSTANTIATECONTRACTPROPOSAL.fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _INSTANTIATECONTRACTPROPOSAL._options = None
  _INSTANTIATECONTRACTPROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260* wasm/InstantiateContractProposal'
  _INSTANTIATECONTRACT2PROPOSAL.fields_by_name['code_id']._options = None
  _INSTANTIATECONTRACT2PROPOSAL.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _INSTANTIATECONTRACT2PROPOSAL.fields_by_name['msg']._options = None
  _INSTANTIATECONTRACT2PROPOSAL.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _INSTANTIATECONTRACT2PROPOSAL.fields_by_name['funds']._options = None
  _INSTANTIATECONTRACT2PROPOSAL.fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _INSTANTIATECONTRACT2PROPOSAL._options = None
  _INSTANTIATECONTRACT2PROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*!wasm/InstantiateContract2Proposal'
  _MIGRATECONTRACTPROPOSAL.fields_by_name['code_id']._options = None
  _MIGRATECONTRACTPROPOSAL.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _MIGRATECONTRACTPROPOSAL.fields_by_name['msg']._options = None
  _MIGRATECONTRACTPROPOSAL.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _MIGRATECONTRACTPROPOSAL._options = None
  _MIGRATECONTRACTPROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\034wasm/MigrateContractProposal'
  _SUDOCONTRACTPROPOSAL.fields_by_name['msg']._options = None
  _SUDOCONTRACTPROPOSAL.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _SUDOCONTRACTPROPOSAL._options = None
  _SUDOCONTRACTPROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\031wasm/SudoContractProposal'
  _EXECUTECONTRACTPROPOSAL.fields_by_name['msg']._options = None
  _EXECUTECONTRACTPROPOSAL.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _EXECUTECONTRACTPROPOSAL.fields_by_name['funds']._options = None
  _EXECUTECONTRACTPROPOSAL.fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _EXECUTECONTRACTPROPOSAL._options = None
  _EXECUTECONTRACTPROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\034wasm/ExecuteContractProposal'
  _UPDATEADMINPROPOSAL.fields_by_name['new_admin']._options = None
  _UPDATEADMINPROPOSAL.fields_by_name['new_admin']._serialized_options = b'\362\336\037\020yaml:\"new_admin\"'
  _UPDATEADMINPROPOSAL._options = None
  _UPDATEADMINPROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\030wasm/UpdateAdminProposal'
  _CLEARADMINPROPOSAL._options = None
  _CLEARADMINPROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\027wasm/ClearAdminProposal'
  _PINCODESPROPOSAL.fields_by_name['title']._options = None
  _PINCODESPROPOSAL.fields_by_name['title']._serialized_options = b'\362\336\037\014yaml:\"title\"'
  _PINCODESPROPOSAL.fields_by_name['description']._options = None
  _PINCODESPROPOSAL.fields_by_name['description']._serialized_options = b'\362\336\037\022yaml:\"description\"'
  _PINCODESPROPOSAL.fields_by_name['code_ids']._options = None
  _PINCODESPROPOSAL.fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs\362\336\037\017yaml:\"code_ids\"'
  _PINCODESPROPOSAL._options = None
  _PINCODESPROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\025wasm/PinCodesProposal'
  _UNPINCODESPROPOSAL.fields_by_name['title']._options = None
  _UNPINCODESPROPOSAL.fields_by_name['title']._serialized_options = b'\362\336\037\014yaml:\"title\"'
  _UNPINCODESPROPOSAL.fields_by_name['description']._options = None
  _UNPINCODESPROPOSAL.fields_by_name['description']._serialized_options = b'\362\336\037\022yaml:\"description\"'
  _UNPINCODESPROPOSAL.fields_by_name['code_ids']._options = None
  _UNPINCODESPROPOSAL.fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs\362\336\037\017yaml:\"code_ids\"'
  _UNPINCODESPROPOSAL._options = None
  _UNPINCODESPROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\027wasm/UnpinCodesProposal'
  _ACCESSCONFIGUPDATE.fields_by_name['code_id']._options = None
  _ACCESSCONFIGUPDATE.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _ACCESSCONFIGUPDATE.fields_by_name['instantiate_permission']._options = None
  _ACCESSCONFIGUPDATE.fields_by_name['instantiate_permission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _UPDATEINSTANTIATECONFIGPROPOSAL.fields_by_name['title']._options = None
  _UPDATEINSTANTIATECONFIGPROPOSAL.fields_by_name['title']._serialized_options = b'\362\336\037\014yaml:\"title\"'
  _UPDATEINSTANTIATECONFIGPROPOSAL.fields_by_name['description']._options = None
  _UPDATEINSTANTIATECONFIGPROPOSAL.fields_by_name['description']._serialized_options = b'\362\336\037\022yaml:\"description\"'
  _UPDATEINSTANTIATECONFIGPROPOSAL.fields_by_name['access_config_updates']._options = None
  _UPDATEINSTANTIATECONFIGPROPOSAL.fields_by_name['access_config_updates']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _UPDATEINSTANTIATECONFIGPROPOSAL._options = None
  _UPDATEINSTANTIATECONFIGPROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*$wasm/UpdateInstantiateConfigProposal'
  _STOREANDINSTANTIATECONTRACTPROPOSAL.fields_by_name['wasm_byte_code']._options = None
  _STOREANDINSTANTIATECONTRACTPROPOSAL.fields_by_name['wasm_byte_code']._serialized_options = b'\342\336\037\014WASMByteCode'
  _STOREANDINSTANTIATECONTRACTPROPOSAL.fields_by_name['msg']._options = None
  _STOREANDINSTANTIATECONTRACTPROPOSAL.fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _STOREANDINSTANTIATECONTRACTPROPOSAL.fields_by_name['funds']._options = None
  _STOREANDINSTANTIATECONTRACTPROPOSAL.fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _STOREANDINSTANTIATECONTRACTPROPOSAL._options = None
  _STOREANDINSTANTIATECONTRACTPROPOSAL._serialized_options = b'\030\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*(wasm/StoreAndInstantiateContractProposal'
  _globals['_STORECODEPROPOSAL']._serialized_start=184
  _globals['_STORECODEPROPOSAL']._serialized_end=506
  _globals['_INSTANTIATECONTRACTPROPOSAL']._serialized_start=509
  _globals['_INSTANTIATECONTRACTPROPOSAL']._serialized_end=854
  _globals['_INSTANTIATECONTRACT2PROPOSAL']._serialized_start=857
  _globals['_INSTANTIATECONTRACT2PROPOSAL']._serialized_end=1235
  _globals['_MIGRATECONTRACTPROPOSAL']._serialized_start=1238
  _globals['_MIGRATECONTRACTPROPOSAL']._serialized_end=1450
  _globals['_SUDOCONTRACTPROPOSAL']._serialized_start=1453
  _globals['_SUDOCONTRACTPROPOSAL']._serialized_end=1630
  _globals['_EXECUTECONTRACTPROPOSAL']._serialized_start=1633
  _globals['_EXECUTECONTRACTPROPOSAL']._serialized_end=1929
  _globals['_UPDATEADMINPROPOSAL']._serialized_start=1932
  _globals['_UPDATEADMINPROPOSAL']._serialized_end=2111
  _globals['_CLEARADMINPROPOSAL']._serialized_start=2114
  _globals['_CLEARADMINPROPOSAL']._serialized_end=2250
  _globals['_PINCODESPROPOSAL']._serialized_start=2253
  _globals['_PINCODESPROPOSAL']._serialized_end=2459
  _globals['_UNPINCODESPROPOSAL']._serialized_start=2462
  _globals['_UNPINCODESPROPOSAL']._serialized_end=2672
  _globals['_ACCESSCONFIGUPDATE']._serialized_start=2674
  _globals['_ACCESSCONFIGUPDATE']._serialized_end=2798
  _globals['_UPDATEINSTANTIATECONFIGPROPOSAL']._serialized_start=2801
  _globals['_UPDATEINSTANTIATECONFIGPROPOSAL']._serialized_end=3067
  _globals['_STOREANDINSTANTIATECONTRACTPROPOSAL']._serialized_start=3070
  _globals['_STOREANDINSTANTIATECONTRACTPROPOSAL']._serialized_end=3580
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.gov.v1 import gov_pb2 as cosmos_dot_gov_dot_v1_dot_gov__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63osmos/gov/v1/genesis.proto\x12\rcosmos.gov.v1\x1a\x17\x63osmos/gov/v1/gov.proto\"\xf5\x02\n\x0cGenesisState\x12\x1c\n\x14starting_proposal_id\x18\x01 \x01(\x04\x12(\n\x08\x64\x65posits\x18\x02 \x03(\x0b\x32\x16.cosmos.gov.v1.Deposit\x12\"\n\x05votes\x18\x03 \x03(\x0b\x32\x13.cosmos.gov.v1.Vote\x12*\n\tproposals\x18\x04 \x03(\x0b\x32\x17.cosmos.gov.v1.Proposal\x12\x38\n\x0e\x64\x65posit_params\x18\x05 \x01(\x0b\x32\x1c.cosmos.gov.v1.DepositParamsB\x02\x18\x01\x12\x36\n\rvoting_params\x18\x06 \x01(\x0b\x32\x1b.cosmos.gov.v1.VotingParamsB\x02\x18\x01\x12\x34\n\x0ctally_params\x18\x07 \x01(\x0b\x32\x1a.cosmos.gov.v1.TallyParamsB\x02\x18\x01\x12%\n\x06params\x18\x08 \x01(\x0b\x32\x15.cosmos.gov.v1.ParamsB-Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1'
  _GENESISSTATE.fields_by_name['deposit_params']._options = None
  _GENESISSTATE.fields_by_name['deposit_params']._serialized_options = b'\030\001'
  _GENESISSTATE.fields_by_name['voting_params']._options = None
  _GENESISSTATE.fields_by_name['voting_params']._serialized_options = b'\030\001'
  _GENESISSTATE.fields_by_name['tally_params']._options = None
  _GENESISSTATE.fields_by_name['tally_params']._serialized_options = b'\030\001'
  _globals['_GENESISSTATE']._serialized_start=72
  _globals['_GENESISSTATE']._serialized_end=445
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.applications.fee.v1 import fee_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_fee__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ibc/applications/fee/v1/tx.proto\x12\x17ibc.applications.fee.v1\x1a\x14gogoproto/gogo.proto\x1a!ibc/applications/fee/v1/fee.proto\x1a!ibc/core/channel/v1/channel.proto\"\x8c\x01\n\x10MsgRegisterPayee\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x0f\n\x07relayer\x18\x03 \x01(\t\x12\r\n\x05payee\x18\x04 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x1a\n\x18MsgRegisterPayeeResponse\"\xc4\x01\n\x1cMsgRegisterCounterpartyPayee\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x0f\n\x07relayer\x18\x03 \x01(\t\x12\x39\n\x12\x63ounterparty_payee\x18\x04 \x01(\tB\x1d\xf2\xde\x1f\x19yaml:\"counterparty_payee\":\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"&\n$MsgRegisterCounterpartyPayeeResponse\"\xda\x01\n\x0fMsgPayPacketFee\x12/\n\x03\x66\x65\x65\x18\x01 \x01(\x0b\x32\x1c.ibc.applications.fee.v1.FeeB\x04\xc8\xde\x1f\x00\x12\x31\n\x0esource_port_id\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_port_id\"\x12\x37\n\x11source_channel_id\x18\x03 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"source_channel_id\"\x12\x0e\n\x06signer\x18\x04 \x01(\t\x12\x10\n\x08relayers\x18\x05 \x03(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x19\n\x17MsgPayPacketFeeResponse\"\xbf\x01\n\x14MsgPayPacketFeeAsync\x12J\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x18\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"packet_id\"\x12Q\n\npacket_fee\x18\x02 \x01(\x0b\x32\".ibc.applications.fee.v1.PacketFeeB\x19\xc8\xde\x1f\x00\xf2\xde\x1f\x11yaml:\"packet_fee\":\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x1e\n\x1cMsgPayPacketFeeAsyncResponse2\xef\x03\n\x03Msg\x12m\n\rRegisterPayee\x12).ibc.applications.fee.v1.MsgRegisterPayee\x1a\x31.ibc.applications.fee.v1.MsgRegisterPayeeResponse\x12\x91\x01\n\x19RegisterCounterpartyPayee\x12\x35.ibc.applications.fee.v1.MsgRegisterCounterpartyPayee\x1a=.ibc.applications.fee.v1.MsgRegisterCounterpartyPayeeResponse\x12j\n\x0cPayPacketFee\x12(.ibc.applications.fee.v1.MsgPayPacketFee\x1a\x30.ibc.applications.fee.v1.MsgPayPacketFeeResponse\x12y\n\x11PayPacketFeeAsync\x12-.ibc.applications.fee.v1.MsgPayPacketFeeAsync\x1a\x35.ibc.applications.fee.v1.MsgPayPacketFeeAsyncResponseB7Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _MSGREGISTERPAYEE.fields_by_name['port_id']._options = None
  _MSGREGISTERPAYEE.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _MSGREGISTERPAYEE.fields_by_name['channel_id']._options = None
  _MSGREGISTERPAYEE.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _MSGREGISTERPAYEE._options = None
  _MSGREGISTERPAYEE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGREGISTERCOUNTERPARTYPAYEE.fields_by_name['port_id']._options = None
  _MSGREGISTERCOUNTERPARTYPAYEE.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _MSGREGISTERCOUNTERPARTYPAYEE.fields_by_name['channel_id']._options = None
  _MSGREGISTERCOUNTERPARTYPAYEE.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _MSGREGISTERCOUNTERPARTYPAYEE.fields_by_name['counterparty_payee']._options = None
  _MSGREGISTERCOUNTERPARTYPAYEE.fields_by_name['counterparty_payee']._serialized_options = b'\362\336\037\031yaml:\"counterparty_payee\"'
  _MSGREGISTERCOUNTERPARTYPAYEE._options = None
  _MSGREGISTERCOUNTERPARTYPAYEE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGPAYPACKETFEE.fields_by_name['fee']._options = None
  _MSGPAYPACKETFEE.fields_by_name['fee']._serialized_options = b'\310\336\037\000'
  _MSGPAYPACKETFEE.fields_by_name['source_port_id']._options = None
  _MSGPAYPACKETFEE.fields_by_name['source_port_id']._serialized_options = b'\362\336\037\025yaml:\"source_port_id\"'
  _MSGPAYPACKETFEE.fields_by_name['source_channel_id']._options = None
  _MSGPAYPACKETFEE.fields_by_name['source_channel_id']._serialized_options = b'\362\336\037\030yaml:\"source_channel_id\"'
  _MSGPAYPACKETFEE._options = None
  _MSGPAYPACKETFEE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGPAYPACKETFEEASYNC.fields_by_name['packet_id']._options = None
  _MSGPAYPACKETFEEASYNC.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000\362\336\037\020yaml:\"packet_id\"'
  _MSGPAYPACKETFEEASYNC.fields_by_name['packet_fee']._options = None
  _MSGPAYPACKETFEEASYNC.fields_by_name['packet_fee']._serialized_options = b'\310\336\037\000\362\336\037\021yaml:\"packet_fee\"'
  _MSGPAYPACKETFEEASYNC._options = None
  _MSGPAYPACKETFEEASYNC._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGREGISTERPAYEE']._serialized_start=154
  _globals['_MSGREGISTERPAYEE']._serialized_end=294
  _globals['_MSGREGISTERPAYEERESPONSE']._serialized_start=296
  _globals['_MSGREGISTERPAYEERESPONSE']._serialized_end=322
  _globals['_MSGREGISTERCOUNTERPARTYPAYEE']._serialized_start=325
  _globals['_MSGREGISTERCOUNTERPARTYPAYEE']._serialized_end=521
  _globals['_MSGREGISTERCOUNTERPARTYPAYEERESPONSE']._serialized_start=523
  _globals['_MSGREGISTERCOUNTERPARTYPAYEERESPONSE']._serialized_end=561
  _globals['_MSGPAYPACKETFEE']._serialized_start=564
  _globals['_MSGPAYPACKETFEE']._serialized_end=782
  _globals['_MSGPAYPACKETFEERESPONSE']._serialized_start=784
  _globals['_MSGPAYPACKETFEERESPONSE']._serialized_end=809
  _globals['_MSGPAYPACKETFEEASYNC']._serialized_start=812
  _globals['_MSGPAYPACKETFEEASYNC']._serialized_end=1003
  _globals['_MSGPAYPACKETFEEASYNCRESPONSE']._serialized_start=1005
  _globals['_MSGPAYPACKETFEEASYNCRESPONSE']._serialized_end=1035
  _globals['_MSG']._serialized_start=1038
  _globals['_MSG']._serialized_end=1533
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from injective.insurance.v1beta1 import query_pb2 as injective_dot_insurance_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InsuranceParams = channel.unary_unary(
                '/injective.insurance.v1beta1.Query/InsuranceParams',
                request_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceParamsRequest.SerializeToString,
                response_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceParamsResponse.FromString,
                )
        self.InsuranceFund = channel.unary_unary(
                '/injective.insurance.v1beta1.Query/InsuranceFund',
                request_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundRequest.SerializeToString,
                response_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundResponse.FromString,
                )
        self.InsuranceFunds = channel.unary_unary(
                '/injective.insurance.v1beta1.Query/InsuranceFunds',
                request_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundsRequest.SerializeToString,
                response_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundsResponse.FromString,
                )
        self.EstimatedRedemptions = channel.unary_unary(
                '/injective.insurance.v1beta1.Query/EstimatedRedemptions',
                request_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryEstimatedRedemptionsRequest.SerializeToString,
                response_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryEstimatedRedemptionsResponse.FromString,
                )
        self.PendingRedemptions = channel.unary_unary(
                '/injective.insurance.v1beta1.Query/PendingRedemptions',
                request_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryPendingRedemptionsRequest.SerializeToString,
                response_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryPendingRedemptionsResponse.FromString,
                )
        self.InsuranceModuleState = channel.unary_unary(
                '/injective.insurance.v1beta1.Query/InsuranceModuleState',
                request_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
                response_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def InsuranceParams(self, request, context):
        """Retrieves insurance params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsuranceFund(self, request, context):
        """Retrieves individual insurance fund information from market id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsuranceFunds(self, request, context):
        """Retrieves all insurance funds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimatedRedemptions(self, request, context):
        """Retrives the value of insurance fund share token at current price (not
        pending redemption)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PendingRedemptions(self, request, context):
        """Retrieves pending redemptions' share token at current price
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InsuranceModuleState(self, request, context):
        """Retrieves the entire insurance module's state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InsuranceParams': grpc.unary_unary_rpc_method_handler(
                    servicer.InsuranceParams,
                    request_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceParamsRequest.FromString,
                    response_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceParamsResponse.SerializeToString,
            ),
            'InsuranceFund': grpc.unary_unary_rpc_method_handler(
                    servicer.InsuranceFund,
                    request_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundRequest.FromString,
                    response_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundResponse.SerializeToString,
            ),
            'InsuranceFunds': grpc.unary_unary_rpc_method_handler(
                    servicer.InsuranceFunds,
                    request_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundsRequest.FromString,
                    response_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundsResponse.SerializeToString,
            ),
            'EstimatedRedemptions': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimatedRedemptions,
                    request_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryEstimatedRedemptionsRequest.FromString,
                    response_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryEstimatedRedemptionsResponse.SerializeToString,
            ),
            'PendingRedemptions': grpc.unary_unary_rpc_method_handler(
                    servicer.PendingRedemptions,
                    request_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryPendingRedemptionsRequest.FromString,
                    response_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryPendingRedemptionsResponse.SerializeToString,
            ),
            'InsuranceModuleState': grpc.unary_unary_rpc_method_handler(
                    servicer.InsuranceModuleState,
                    request_deserializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.FromString,
                    response_serializer=injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.insurance.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def InsuranceParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.insurance.v1beta1.Query/InsuranceParams',
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceParamsRequest.SerializeToString,
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsuranceFund(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.insurance.v1beta1.Query/InsuranceFund',
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundRequest.SerializeToString,
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsuranceFunds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.insurance.v1beta1.Query/InsuranceFunds',
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundsRequest.SerializeToString,
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryInsuranceFundsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimatedRedemptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.insurance.v1beta1.Query/EstimatedRedemptions',
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryEstimatedRedemptionsRequest.SerializeToString,
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryEstimatedRedemptionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PendingRedemptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.insurance.v1beta1.Query/PendingRedemptions',
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryPendingRedemptionsRequest.SerializeToString,
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryPendingRedemptionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InsuranceModuleState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.insurance.v1beta1.Query/InsuranceModuleState',
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
            injective_dot_insurance_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63osmos/authz/v1beta1/tx.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a cosmos/authz/v1beta1/authz.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\xbd\x01\n\x08MsgGrant\x12)\n\x07granter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x07grantee\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x35\n\x05grant\x18\x03 \x01(\x0b\x32\x1b.cosmos.authz.v1beta1.GrantB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:$\x82\xe7\xb0*\x07granter\x8a\xe7\xb0*\x13\x63osmos-sdk/MsgGrant\"\"\n\x0fMsgExecResponse\x12\x0f\n\x07results\x18\x01 \x03(\x0c\"\x9a\x01\n\x07MsgExec\x12)\n\x07grantee\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12?\n\x04msgs\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB\x1b\xca\xb4-\x17\x63osmos.base.v1beta1.Msg:#\x82\xe7\xb0*\x07grantee\x8a\xe7\xb0*\x12\x63osmos-sdk/MsgExec\"\x12\n\x10MsgGrantResponse\"\x9e\x01\n\tMsgRevoke\x12)\n\x07granter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x07grantee\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x14\n\x0cmsg_type_url\x18\x03 \x01(\t:%\x82\xe7\xb0*\x07granter\x8a\xe7\xb0*\x14\x63osmos-sdk/MsgRevoke\"\x13\n\x11MsgRevokeResponse\"(\n\x15MsgExecCompatResponse\x12\x0f\n\x07results\x18\x01 \x03(\x0c\"m\n\rMsgExecCompat\x12)\n\x07grantee\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x0c\n\x04msgs\x18\x02 \x03(\t:#\x82\xe7\xb0*\x07grantee\x8a\xe7\xb0*\x12\x63osmos-sdk/MsgExec2\xdf\x02\n\x03Msg\x12O\n\x05Grant\x12\x1e.cosmos.authz.v1beta1.MsgGrant\x1a&.cosmos.authz.v1beta1.MsgGrantResponse\x12L\n\x04\x45xec\x12\x1d.cosmos.authz.v1beta1.MsgExec\x1a%.cosmos.authz.v1beta1.MsgExecResponse\x12R\n\x06Revoke\x12\x1f.cosmos.authz.v1beta1.MsgRevoke\x1a\'.cosmos.authz.v1beta1.MsgRevokeResponse\x12^\n\nExecCompat\x12#.cosmos.authz.v1beta1.MsgExecCompat\x1a+.cosmos.authz.v1beta1.MsgExecCompatResponse\x1a\x05\x80\xe7\xb0*\x01\x42*Z$github.com/cosmos/cosmos-sdk/x/authz\xc8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz\310\341\036\000'
  _MSGGRANT.fields_by_name['granter']._options = None
  _MSGGRANT.fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGGRANT.fields_by_name['grantee']._options = None
  _MSGGRANT.fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGGRANT.fields_by_name['grant']._options = None
  _MSGGRANT.fields_by_name['grant']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGGRANT._options = None
  _MSGGRANT._serialized_options = b'\202\347\260*\007granter\212\347\260*\023cosmos-sdk/MsgGrant'
  _MSGEXEC.fields_by_name['grantee']._options = None
  _MSGEXEC.fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGEXEC.fields_by_name['msgs']._options = None
  _MSGEXEC.fields_by_name['msgs']._serialized_options = b'\312\264-\027cosmos.base.v1beta1.Msg'
  _MSGEXEC._options = None
  _MSGEXEC._serialized_options = b'\202\347\260*\007grantee\212\347\260*\022cosmos-sdk/MsgExec'
  _MSGREVOKE.fields_by_name['granter']._options = None
  _MSGREVOKE.fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGREVOKE.fields_by_name['grantee']._options = None
  _MSGREVOKE.fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGREVOKE._options = None
  _MSGREVOKE._serialized_options = b'\202\347\260*\007granter\212\347\260*\024cosmos-sdk/MsgRevoke'
  _MSGEXECCOMPAT.fields_by_name['grantee']._options = None
  _MSGEXECCOMPAT.fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGEXECCOMPAT._options = None
  _MSGEXECCOMPAT._serialized_options = b'\202\347\260*\007grantee\212\347\260*\022cosmos-sdk/MsgExec'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _globals['_MSGGRANT']._serialized_start=210
  _globals['_MSGGRANT']._serialized_end=399
  _globals['_MSGEXECRESPONSE']._serialized_start=401
  _globals['_MSGEXECRESPONSE']._serialized_end=435
  _globals['_MSGEXEC']._serialized_start=438
  _globals['_MSGEXEC']._serialized_end=592
  _globals['_MSGGRANTRESPONSE']._serialized_start=594
  _globals['_MSGGRANTRESPONSE']._serialized_end=612
  _globals['_MSGREVOKE']._serialized_start=615
  _globals['_MSGREVOKE']._serialized_end=773
  _globals['_MSGREVOKERESPONSE']._serialized_start=775
  _globals['_MSGREVOKERESPONSE']._serialized_end=794
  _globals['_MSGEXECCOMPATRESPONSE']._serialized_start=796
  _globals['_MSGEXECCOMPATRESPONSE']._serialized_end=836
  _globals['_MSGEXECCOMPAT']._serialized_start=838
  _globals['_MSGEXECCOMPAT']._serialized_end=947
  _globals['_MSG']._serialized_start=950
  _globals['_MSG']._serialized_end=1301
# @@protoc_insertion_point(module_scope)
